Learn R Programming

USpopcenters (version 0.1.1)

US_mean_center2010: Mean center of population of the US according to the 2010 census

Description

A data set of the latitude and longitude coordinates of the mean center of population (centroid) of the United States. The total US populations according to the 2010 decennial census is also included.

Usage

US_mean_center2010

Arguments

Format

A tibble with 1 row and 3 columns

POPULATION

The population of the US

LATITUDE

The latitude coordinate of the mean center of population (centroid) of the US (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the mean center of population (centroid) of the US (positive is east; negative is west)

See Also

Median center of population of the US: US_median_center2010

Other 2010 census centers of population: state2010; county2010; tract2010; block_group2010

2000 census centers of population: state2000; county2000; tract2000; block_group2000

Examples

Run this code
US_mean_center2010

Run the code above in your browser using DataLab