Learn R Programming

USpopcenters (version 0.1.1)

county2000: Centers of population of US counties according to the 2000 census

Description

A data set of the latitude and longitude coordinates of the centers of population (centroids) of counties (and county equivalents) in the US states plus the District of Columbia, Puerto Rico, American Samoa, Guam, the Northern Mariana Islands, and the US Virgin Islands. Populations according to the 2000 decennial census are also included.

Usage

county2000

Arguments

Format

A tibble with 3,232 rows and 6 variables:

STATEFP

The two-digit GEOID of the state where the county is located

COUNTYFP

The last three digits of the five-digit GEOID of the county

COUNAME

The name of the county

POPULATION

The population of the county

LATITUDE

The latitude coordinate of the center of population (centroid) of the county (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the center of population (centroid) of the county (positive is east; negative is west)

Details

This had to be stitched together from separate state files.

Unlike county2010, county2000 contains data from American Samoa, Guam, the Northern Mariana Islands, and the US Virgin Islands. Also unlike county2010, county2000 does not contain the STNAME (state name) column.

See Also

Other 2000 census centers of population: state2000; tract2000; block_group2000

2010 census centers of population: state2010; county2010; tract2010; block_group2010; US_mean_center2010; US_median_center2010

Examples

Run this code
county2000

Run the code above in your browser using DataLab