Learn R Programming

USpopcenters (version 0.1.1)

county2010: Centers of population of US counties according to the 2010 census

Description

A data set of the latitude and longitude coordinates of the centers of population (centroids) of counties (and county equivalents) in the US states plus the District of Columbia and Puerto Rico. Populations according to the 2010 decennial census are also included.

Usage

county2010

Arguments

Format

A tibble with 3,221 rows and 7 variables:

STATEFP

The two-digit GEOID of the state where the county is located

COUNTYFP

The last three digits of the five-digit GEOID of the county

COUNAME

The name of the county

STNAME

The name of the state where the county is located

POPULATION

The population of the county

LATITUDE

The latitude coordinate of the center of population (centroid) of the county (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the center of population (centroid) of the county (positive is east; negative is west)

Details

Unlike county2000, county2010 does not contain data from American Samoa, Guam, the Northern Mariana Islands, or the US Virgin Islands. Also unlike county2010, it contains the the state name column STNAME.

See Also

Other 2010 census centers of population: state2010; tract2010; block_group2010; US_mean_center2010; US_median_center2010

2000 census centers of population: state2000; county2000; tract2000; block_group2000

Examples

Run this code
county2010

Run the code above in your browser using DataLab