Learn R Programming

USpopcenters (version 0.1.1)

state2000: Centers of population of US states according to the 2000 census

Description

A data set of the latitude and longitude coordinates of the centers of population (centroids) of the US states plus the District of Columbia. Populations according to the 2000 decennial census are also included.

Usage

state2000

Arguments

Format

A tibble with 51 rows and 5 columns

STATEFP

The two-digit GEOID of the state

STNAME

The name of the state

POPULATION

The population of the state

LATITUDE

The latitude coordinate of the center of population (centroid) of the state (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the center of population (centroid) of the state (positive is east; negative is west)

Details

Note that this does not contain Puerto Rico's data, unlike state2010.

Also, unlike county2000, state2000 does not contain data from Puerto Rico, American Samoa, Guam, the Northern Mariana Islands, or the US Virgin Islands.

The source data file on the US census website has different column names than what its data dictionary reports. The data dictionary's version of the column names were used, since they are consistent with the majority of the other data files and data dictionaries on the census website.

See Also

Other 2000 census centers of population: county2000; tract2000; block_group2000;

2010 census centers of population: state2010; county2010; tract2010; block_group2010; US_mean_center2010; US_median_center2010

Examples

Run this code
state2000

Run the code above in your browser using DataLab