Learn R Programming

USpopcenters (version 0.1.1)

state2010: Centers of population of US states according to the 2010 census

Description

A data set of the latitude and longitude coordinates of the centers of population (centroids) of the US states plus the District of Columbia and Puerto Rico. Populations according to the 2010 decennial census are also included.

Usage

state2010

Arguments

Format

A tibble with 52 rows and 5 columns

STATEFP

The two-digit GEOID of the state

STNAME

The name of the state

POPULATION

The population of the state

LATITUDE

The latitude coordinate of the center of population (centroid) of the state (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the center of population (centroid) of the state (positive is east; negative is west)

Details

Note that this contains Puerto Rico data, unlike state2000.

See Also

Other 2010 census centers of population: county2010; tract2010; block_group2010; US_mean_center2010; US_median_center2010

2000 census centers of population: state2000; county2000; tract2000; block_group2000

Examples

Run this code
state2010

Run the code above in your browser using DataLab