Learn R Programming

USpopcenters (version 0.1.1)

tract2010: Centers of population of US census tracts according to the 2010 census

Description

A data set of the latitude and longitude coordinates of the centers of population (centroids) of census tracts in the US states plus the District of Columbia and Puerto Rico. Populations according to the 2010 decennial census are also included.

Usage

tract2010

Arguments

Format

A tibble with 74,002 rows and 6 variables:

STATEFP

The two-digit GEOID of the state where the tract is located

COUNTYFP

The last three digits of the five-digit GEOID of the county where the tract is located

TRACTCE

The last six digits of the eleven-digit GEOID of the tract

POPULATION

The population of the tract

LATITUDE

The latitude coordinate of the center of population (centroid) of the tract (positive is north; negative is south)

LONGITUDE

The longitude coordinate of the center of population (centroid) of the tract (positive is east; negative is west)

See Also

Other 2010 census centers of population: state2010; county2010; block_group2010; US_mean_center2010; US_median_center2010

2000 census centers of population: state2000; county2000; tract2000; block_group2000

Examples

Run this code
tract2010

Run the code above in your browser using DataLab